@@ -323,15 +323,15 @@ while (time < $s) {
     $F->bezier({'coordinates' => \@coords, 'points' => 100});
 } ## end foreach my $z (1 .. (40 * $factor...))
 
-if ($XX > 255) {
+{
     print_it($F, 'Testing TrueType Font Rendering (random height/width)');
 
     my $g = time + $factor;
     while( time < $g) {
         my $x  = int(rand(600 * $xm));
         my $y  = int(rand(900 * $ym));
-        my $h  = int(rand(300 * $ym));
-        my $ws = rand(4);
+        my $h  = 4 + ($YY < 128) ? rand(20) : int(rand(300 * $ym));
+        my $ws = ($XX < 256) ? rand(2) : rand(4);
     
         my $b = $F->ttf_print(
             {
@@ -339,7 +339,7 @@ if ($XX > 255) {
                   'y'            => $y,
                   'height'       => $h,
                   'wscale'       => $ws,
-                  'color'        => sprintf('%x%x%x%x', int(rand(256)), int(rand(256)), int(rand(256)), 255),
+                  'color'        => sprintf('%02x%02x%02x', int(rand(256)), int(rand(256)), int(rand(256))),
                   'text'         => 'GFB',
                   'bounding_box' => 1,
                   'center'       => 3
@@ -455,7 +455,7 @@ sleep $factor;
 
 print_it($F, 'Testing Image blitting');
 
-my $image = $F->load_image(
+$image = $F->load_image(
     {
         'x'    => 0,
           'y'    => 0,
@@ -488,8 +488,8 @@ sub print_it {
         my $b = $fb->ttf_print(
             {
                 'x'            => 5  * $xm,
-                'y'            => 30 * $ym,
-                'height'       => 30 * $ym,
+                'y'            => max(9,20 * $ym),
+                'height'       => max(10,20 * $ym),
                 'color'        => '00FF00',
                 'text'         => $message,
                 'bounding_box' => 1,
